@@ -129,7 +129,11 @@ class DatabaseConnection(six.with_metaclass(abc.ABCMeta)):
                     if re.match(config[profile]['domain'], hostname):
                         self.profile = profile
                         self._config = config[profile].copy()
-                        self._config['host'] = None  # Use localhost.
+                        # If the profile host matches the current hostname set the
+                        # value to None to force using localhost to prevent cases
+                        # in which the loopback is not configured properly in PostgreSQL.
+                        if hostname == self._config['host']:
+                            self._config['host'] = None
                         break
 
         if connect:
@@ -275,6 +279,8 @@ class DatabaseConnection(six.with_metaclass(abc.ABCMeta)):
             raise RuntimeError('DB has not been initialised.')
 
         dsn_params = self.connection_params
+        dsn_params.pop('password', None)  # Do not keep the password since it may change.
+
         if dsn_params is None:
             raise RuntimeError('cannot determine the DSN parameters. '
                                'The DB may be disconnected.')
@@ -285,23 +291,32 @@ class DatabaseConnection(six.with_metaclass(abc.ABCMeta)):
 
         self.connect_from_parameters(**dsn_params)
 
-    def become_admin(self):
-        """Becomes the admin user."""
+    def become_admin(self, admin=None):
+        """Becomes the admin user.
+
+        If ``admin=None`` defaults to the ``admin`` value in the current profile.
+
+        """
 
         assert self.profile is not None, \
             'this connection was not initialised from a profile. Try using become().'
 
         assert 'admin' in self._config, 'admin user not defined in profile'
 
-        self.become(self._config['admin'])
+        self.become(admin or self._config['admin'])
 
-    def become_user(self):
-        """Becomes the read-only user."""
+    def become_user(self, user=None):
+        """Becomes the read-only user.
+
+        If ``user=None`` defaults to the ``user`` value in the current profile.
+
+        """
 
         assert self.profile is not None, \
             'this connection was not initialised from a profile. Try using become().'
 
-        user = self._config['user'] if 'user' in self._config else None
+        if user is None:
+            user = self._config['user'] if 'user' in self._config else None
 
         self.become(user)
 
