@@ -6,9 +6,10 @@
 # @Filename: targetdb.py
 # @License: BSD 3-clause (http://www.opensource.org/licenses/BSD-3-Clause)
 
-from peewee import (AutoField, BigIntegerField, BooleanField,
-                    DeferredThroughModel, DoubleField, FloatField,
-                    ForeignKeyField, IntegerField, ManyToManyField,
+
+from peewee import (AutoField, BooleanField, DateTimeField,
+                    DeferredThroughModel, DoubleField,
+                    FloatField, ForeignKeyField, IntegerField,
                     SmallIntegerField, TextField)
 from playhouse.postgres_ext import ArrayField
 
@@ -38,9 +39,23 @@ class Version(TargetdbBase):
         table_name = 'version'
 
 
+class ObsMode(TargetdbBase):
+    label = TextField(null=False)
+    min_moon_sep = FloatField(null=True)
+    min_deltav_ks91 = FloatField(null=True)
+    min_twilight_ang = FloatField(null=True)
+    max_airmass = FloatField(null=True)
+
+    class Meta:
+        table_name = 'obsmode'
+
+
 class Cadence(TargetdbBase):
     label = TextField(null=False)
+    label_version = TextField(null=False)
+    label_root = TextField(null=False)
     nepochs = IntegerField(null=True)
+    skybrightness = ArrayField(field_class=FloatField, null=True)
     delta = ArrayField(field_class=FloatField, null=True)
     delta_max = ArrayField(field_class=FloatField, null=True)
     delta_min = ArrayField(field_class=FloatField, null=True)
@@ -49,6 +64,7 @@ class Cadence(TargetdbBase):
     pk = AutoField()
     skybrightness = ArrayField(field_class=FloatField, null=True)
     max_length = ArrayField(field_class=FloatField, null=True)
+    obsmode_pk = ArrayField(field_class=TextField, null=True)
 
     class Meta:
         table_name = 'cadence'
@@ -63,6 +79,7 @@ class Observatory(TargetdbBase):
 
 
 class Field(TargetdbBase):
+
     pk = AutoField()
     field_id = IntegerField(null=False)
     racen = DoubleField(null=False)
@@ -85,13 +102,44 @@ class Field(TargetdbBase):
         table_name = 'field'
 
 
+class DesignMode(TargetdbBase):
+    label = TextField(null=False)
+    boss_skies_min = IntegerField(null=True)
+    boss_skies_fov = ArrayField(field_class=DoubleField, null=True)
+    apogee_skies_min = IntegerField(null=True)
+    apogee_skies_fov = ArrayField(field_class=DoubleField, null=True)
+    boss_stds_min = IntegerField(null=True)
+    boss_stds_mags_min = ArrayField(field_class=DoubleField, null=True)
+    boss_stds_mags_max = ArrayField(field_class=DoubleField, null=True)
+    boss_stds_fov = ArrayField(field_class=DoubleField, null=True)
+    apogee_stds_min = IntegerField(null=True)
+    apogee_stds_mags_min = ArrayField(field_class=DoubleField, null=True)
+    apogee_stds_mags_max = ArrayField(field_class=DoubleField, null=True)
+    apogee_stds_fov = ArrayField(field_class=DoubleField, null=True)
+    boss_bright_limit_targets_min = ArrayField(field_class=DoubleField, null=True)
+    boss_bright_limit_targets_max = ArrayField(field_class=DoubleField, null=True)
+    boss_sky_neighbors_targets = ArrayField(field_class=DoubleField, null=True)
+    apogee_bright_limit_targets_min = ArrayField(field_class=DoubleField, null=True)
+    apogee_bright_limit_targets_max = ArrayField(field_class=DoubleField, null=True)
+    apogee_trace_diff_targets = ArrayField(field_class=DoubleField, null=True)
+    apogee_sky_neighbors_targets = ArrayField(field_class=DoubleField, null=True)
+
+    class Meta:
+        table_name = 'design_mode'
+
+
 class Design(TargetdbBase):
     field = ForeignKeyField(column_name='field_pk',
                             field='pk',
                             model=Field,
-                            null=True)
-    exposure = BigIntegerField(null=True)
+                            null=True,
+                            backref="designs")
+    exposure = IntegerField(null=True)
     pk = AutoField()
+    design_mode_pk = ForeignKeyField(column_name='design_mode_pk',
+                                     field='label',
+                                     model=DesignMode,
+                                     null=True)
 
     class Meta:
         table_name = 'design'
@@ -100,6 +148,7 @@ class Design(TargetdbBase):
 class Instrument(TargetdbBase):
     label = TextField(null=True)
     pk = AutoField()
+    default_lambda_eff = FloatField()
 
     class Meta:
         table_name = 'instrument'
@@ -171,6 +220,7 @@ class Carton(TargetdbBase):
     version = ForeignKeyField(column_name='version_pk',
                               field='pk',
                               model=Version)
+    run_on = DateTimeField()
 
     class Meta:
         table_name = 'carton'
@@ -222,6 +272,9 @@ class CartonToTarget(TargetdbBase):
     instrument = ForeignKeyField(Instrument,
                                  column_name='instrument_pk',
                                  field='pk')
+    delta_ra = DoubleField()
+    delta_dec = DoubleField()
+    inertial = BooleanField()
 
     class Meta:
         table_name = 'carton_to_target'
